from setuptools import setup, find_packages

setup(
    name='cometai_core',
    version='0.0.7',
    packages=find_packages(),
    description='A simple example package',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Ethan Hou',
    author_email='ethanfhou10@gmail.com',
    url='https://github.com/cometai/core',
    license='MIT',
    install_requires=[
       'appdirs',
        'attrs',
        'beautifulsoup4',
        'bs4',
        'certifi',
        'charset-normalizer',
        'cssselect',
        'exceptiongroup',
        'fake-useragent',
        'h11',
        'idna',
        'importlib_metadata',
        'importlib_resources',
        'lxml',
        'lxml_html_clean',
        'outcome',
        'parse',
        'pyee',
        'pyppeteer',
        'pyquery',
        'PySocks',
        'python-dotenv',
        'requests',
        'requests-html',
        'selenium',
        'sniffio',
        'sortedcontainers',
        'soupsieve',
        'trio',
        'trio-websocket',
        'typing_extensions',
        'urllib3',
        'w3lib',
        'websockets',
        'wsproto',
        'zipper'
    ],
)
